@@ -58,58 +58,6 @@ format_parameters.default <- function(model, brackets = c("[", "]"), ...) {
 }
 
 
-#' @export
-format_parameters.glmm <- function(model, brackets = c("[", "]"), ...) {
-  .format_parameter_default(model, effects = "all", brackets = brackets)
-}
-
-
-
-#' @export
-format_parameters.rma <- function(model, ...) {
-  params <- insight::find_parameters(model, flatten = TRUE)
-  names(params) <- params
-  params
-}
-
-
-#' @export
-format_parameters.mediate <- function(model, ...) {
-  params <- insight::find_parameters(model, flatten = TRUE)
-  params <- trimws(gsub("(.*)\\((.*)\\)$", "\\1", params))
-  names(params) <- params
-  params[params == "ACME"] <- "Indirect Effect (ACME)"
-  params[params == "ADE"] <- "Direct Effect (ADE)"
-  params
-}
-
-
-#' @importFrom utils packageVersion
-#' @export
-format_parameters.meta_random <- function(model, ...) {
-  params <- insight::find_parameters(model, flatten = TRUE)
-  names(params) <- params
-  params
-}
-
-#' @export
-format_parameters.meta_fixed <- format_parameters.meta_random
-
-#' @export
-format_parameters.meta_bma <- format_parameters.meta_random
-
-
-
-#' @export
-format_parameters.merModList <- function(model, brackets = c("[", "]"), ...) {
-  .format_parameter_default(model[[1]], brackets = brackets)
-}
-
-
-#' @export
-format_parameters.mira <- format_parameters.rma
-
-
 #' @export
 format_parameters.parameters_model <- function(model, ...) {
   if (!is.null(attributes(model)$pretty_names)) {
@@ -121,38 +69,9 @@ format_parameters.parameters_model <- function(model, ...) {
 
 
 
-
-
-
-# not supported -------------------------------
-
-
-#' @export
-format_parameters.emm_list <- function(model, ...) {
-  NULL
-}
-
-
-#' @export
-format_parameters.margins <- function(model, ...) {
-  NULL
-}
-
-
-#' @export
-format_parameters.mle2 <- function(model, ...) {
-  NULL
-}
-
-
-
-
-
-
 # Utilities ---------------------------------------------------------------
 
 
-
 .format_parameter_default <- function(model, effects = "fixed", brackets = c("[", "]")) {
   original_names <- names <- insight::find_parameters(model, effects = effects, flatten = TRUE)
   info <- insight::model_info(model, verbose = FALSE)
@@ -257,11 +176,11 @@ format_parameters.mle2 <- function(model, ...) {
   }
 
   # "types$Parameter" here is cleaned, i.e. patterns like "log()", "as.factor()"
-  # etc. are removed. However, these patterns are needed in "parameters_table()",
+  # etc. are removed. However, these patterns are needed in "format_table()",
   # code-line x$Parameter <- attributes(x)$pretty_names[x$Parameter]
   # when we use "types$Parameter" here, matching of pretty names does not work,
   # so output will be NA resp. blank fields... Thus, I think we should use
-  # the original paramter-names here.
+  # the original parameter-names here.
 
   names(names) <- original_names # types$Parameter
   names
@@ -360,16 +279,19 @@ format_parameters.mle2 <- function(model, ...) {
   paste0(variable, " ", brackets[1], level, brackets[2])
 }
 
+
 #' @keywords internal
 .format_poly <- function(name, variable, type, degree, brackets = c("[", "]")) {
   paste0(variable, " ", brackets[1], format_order(as.numeric(degree), textual = FALSE), " degree", brackets[2])
 }
 
+
 #' @keywords internal
 .format_log <- function(name, variable, type, brackets = c("[", "]")) {
   paste0(variable, " ", brackets[1], gsub("(.*)\\((.*)\\)", "\\1", name), brackets[2])
 }
 
+
 #' @keywords internal
 .format_ordered <- function(degree, brackets = c("[", "]")) {
   switch(
