@@ -58,7 +58,7 @@ p_value.lmerMod <- function(model, method = "wald", ...) {
 #' @description Parameters from (linear) mixed models.
 #'
 #' @param model A mixed model.
-#' @param effects Should parameters for fixed effects, random effects or both be returned? Only applies to mixed models. May be abbreviated.
+#' @param effects Should parameters for fixed effects (\code{"fixed"}), random effects (\code{"random"}) or both (\code{"all"}) be returned? Only applies to mixed models. May be abbreviated.
 #' @param details Logical, if \code{TRUE}, a summary of the random effects is included. See \code{\link{random_parameters}} for details.
 #' @param df_method Method for computing degrees of freedom for p values, standard errors and confidence intervals (CI). May be \code{"wald"} (default, see \code{\link{degrees_of_freedom}}), \code{"ml1"} (see \code{\link{dof_ml1}}), \code{"betwithin"} (see \code{\link{dof_betwithin}}), \code{"satterthwaite"} (see \code{\link{dof_satterthwaite}}) or \code{"kenward"} (see \code{\link{dof_kenward}}). The options \code{df_method = "boot"}, \code{df_method = "profile"} and \code{df_method = "uniroot"} only affect confidence intervals; in this case, bootstrapped resp. profiled confidence intervals are computed. \code{"uniroot"} only applies to models of class \code{glmmTMB}. Note that when \code{df_method} is not \code{"wald"}, robust standard errors etc. cannot be computed.
 #' @param wb_component Logical, if \code{TRUE} and models contains within- and between-effects (see \code{\link{demean}}), the \code{Component} column will indicate which variables belong to the within-effects, between-effects, and cross-level interactions. By default, the \code{Component} column indicates, which parameters belong to the conditional or zero-inflated component of the model.
@@ -101,6 +101,7 @@ model_parameters.merMod <- function(model,
                                     df_method = "wald",
                                     iterations = 1000,
                                     standardize = NULL,
+                                    effects = "fixed",
                                     exponentiate = FALSE,
                                     robust = FALSE,
                                     details = FALSE,
@@ -113,12 +114,17 @@ model_parameters.merMod <- function(model,
   df_method <- tolower(df_method)
   df_method <- match.arg(df_method, choices = c("wald", "ml1", "betwithin", "satterthwaite", "kenward", "boot", "profile", "uniroot"))
 
-  # Processing
-  if (bootstrap) {
-    params <- bootstrap_parameters(model, iterations = iterations, ci = ci, ...)
-  } else {
-    params <-
-      .extract_parameters_mixed(
+  # which component to return?
+  effects <- match.arg(effects, choices = c("fixed", "random", "all"))
+
+  params <- params_random <- NULL
+
+  if (effects != "random") {
+    # Processing
+    if (bootstrap) {
+      params <- bootstrap_parameters(model, iterations = iterations, ci = ci, ...)
+    } else {
+      params <- .extract_parameters_mixed(
         model,
         ci = ci,
         df_method = df_method,
@@ -128,10 +134,28 @@ model_parameters.merMod <- function(model,
         wb_component = wb_component,
         ...
       )
+    }
+
+    if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
+      params <- .exponentiate_parameters(params, model, exponentiate)
+    }
   }
 
+  if (effects != "fixed") {
+    params_random <- .extract_random_parameters(model, ci = ci, effects = effects)
+  }
 
-  if (exponentiate) params <- .exponentiate_parameters(params)
+  # merge random and fixed effects, if necessary
+  if (is.null(params)) {
+    params <- params_random
+  } else if (!is.null(params_random)) {
+    params$Effects <- "fixed"
+    params$Level <- NA
+    params$Group <- ""
+    # reorder
+    params <- params[match(colnames(params_random), colnames(params))]
+    params <- rbind(params, params_random)
+  }
 
   params <- .add_model_parameters_attributes(
     params,
@@ -277,9 +301,9 @@ standard_error.merMod <- function(model, effects = c("fixed", "random"), method
       if (method %in% c("wald", "satterthwaite")) {
         .data_frame(
           Parameter = insight::find_parameters(model,
-                                               effects = "fixed",
-                                               component = "conditional",
-                                               flatten = TRUE
+            effects = "fixed",
+            component = "conditional",
+            flatten = TRUE
           ),
           SE = .get_se_from_summary(model)
         )
