@@ -80,7 +80,7 @@ parameters_type <- function(model, ...) {
 
 
   data <- insight::get_data(model)
-  if (is.null(data)) {
+  if (is.null(data) || inherits(data, "ts") || nrow(data) == 0) {
     return(NULL)
   }
   reference <- .list_factors_numerics(data, model)
@@ -99,6 +99,12 @@ parameters_type <- function(model, ...) {
     if (!all(interac$Term %in% out$Parameter)) {
       out[paste0(out$Variable, out$Secondary_Variable) == i, "Type"] <- "nested"
     }
+    if (all(interac$Term %in% out$Parameter)) {
+      interac_sec_term <- interac$Secondary_Term[!is.na(interac$Secondary_Term)]
+      if (length(interac_sec_term) && !all(interac_sec_term %in% out$Parameter)) {
+        out[paste0(out$Variable, out$Secondary_Variable) == i, "Type"] <- "simple"
+      }
+    }
   }
   for (i in unique(out$Secondary_Parameter)) {
     if (!is.na(i) && i %in% out$Parameter) {
@@ -156,7 +162,7 @@ parameters_type <- function(model, ...) {
 
 #' @importFrom utils tail head
 #' @keywords internal
-.parameters_type_basic <- function(name, data, reference) {
+.parameters_type_basic <- function(name, data, reference, brackets = c("[", "]")) {
   if (is.na(name)) {
     return(c(NA, NA, NA, NA, NA, NA))
   }
@@ -185,7 +191,7 @@ parameters_type <- function(model, ...) {
       "Association",
       name,
       fac,
-      .format_ordered(gsub(fac, "", name, fixed = TRUE)),
+      .format_ordered(gsub(fac, "", name, fixed = TRUE), brackets = brackets),
       NA
     ))
 
@@ -209,11 +215,8 @@ parameters_type <- function(model, ...) {
     } else {
       type <- "poly"
     }
-    vars <- gsub("poly(", "", name, fixed = TRUE)
-    vars <- unlist(strsplit(vars, ", ", fixed = TRUE))
-    var <- vars[[1]]
-    degree <- vars[[2]]
-    degree <- substr(vars[[2]], nchar(vars[[2]]), nchar(vars[[2]]))
+    var <- .poly_info(name, "name")
+    degree <- .poly_info(name, "degree")
     return(c(type, "Association", name, var, degree, NA))
 
     # Splines
@@ -273,6 +276,26 @@ parameters_type <- function(model, ...) {
 
 
 
+#' @keywords internal
+.poly_info <- function(x, what = "degree") {
+  if (what == "degree") {
+    subs <- "\\4"
+  } else {
+    subs <- "\\2"
+  }
+  p <- "(.*)poly\\((.*),\\s(.*)\\)(.*)"
+  tryCatch(
+    {
+      trimws(sub(p, replacement = subs, x))
+    },
+    error = function(x) {
+      1
+    }
+  )
+}
+
+
+
 #' @keywords internal
 .list_factors_numerics <- function(data, model) {
   out <- list()
