@@ -1,6 +1,9 @@
 #' Pool Model Parameters
 #'
-#' This function "pools" (i.e. combines) model parameters in a similar fashion as \code{mice::pool()}. However, this function pools parameters from \code{parameters_model} objects, as returned by \code{\link{model_parameters}}.
+#' This function "pools" (i.e. combines) model parameters in a similar fashion
+#' as \code{mice::pool()}. However, this function pools parameters from
+#' \code{parameters_model} objects, as returned by
+#' \code{\link{model_parameters}}.
 #'
 #' @param x A list of \code{parameters_model} objects, as returned by
 #'   \code{\link{model_parameters}}, or a list of model-objects that is
@@ -8,6 +11,7 @@
 #' @param ... Currently not used.
 #' @inheritParams model_parameters.default
 #' @inheritParams bootstrap_model
+#' @inheritParams model_parameters.merMod
 #'
 #' @note Models with multiple components, (for instance, models with zero-inflation,
 #'   where predictors appear in the count and zero-inflated part) may fail in
@@ -22,14 +26,15 @@
 #'   small samples (\cite{Barnard and Rubin, 1999}).
 #'
 #' @references
-#' Barnard, J. and Rubin, D.B. (1999). Small sample degrees of freedom with multiple imputation. Biometrika, 86, 948-955.
-#' Rubin, D.B. (1987). Multiple Imputation for Nonresponse in Surveys. New York: John Wiley and Sons.
+#' Barnard, J. and Rubin, D.B. (1999). Small sample degrees of freedom with
+#' multiple imputation. Biometrika, 86, 948-955. Rubin, D.B. (1987). Multiple
+#' Imputation for Nonresponse in Surveys. New York: John Wiley and Sons.
 #'
 #' @examples
 #' # example for multiple imputed datasets
 #' if (require("mice")) {
 #'   data("nhanes2")
-#'   imp <- mice(nhanes2)
+#'   imp <- mice(nhanes2, printFlag = FALSE)
 #'   models <- lapply(1:5, function(i) {
 #'     lm(bmi ~ age + hyp + chl, data = complete(imp, action = i))
 #'   })
@@ -43,7 +48,12 @@
 #' @importFrom stats var pt
 #' @importFrom insight is_model_supported is_model
 #' @export
-pool_parameters <- function(x, exponentiate = FALSE, component = "conditional", verbose = TRUE, ...) {
+pool_parameters <- function(x,
+                            exponentiate = FALSE,
+                            component = "conditional",
+                            details = FALSE,
+                            verbose = TRUE,
+                            ...) {
 
   # check input, save original model -----
 
@@ -52,7 +62,7 @@ pool_parameters <- function(x, exponentiate = FALSE, component = "conditional",
 
   if (all(sapply(x, insight::is_model)) && all(sapply(x, insight::is_model_supported))) {
     original_model <- x[[1]]
-    x <- lapply(x, model_parameters, component = component, ...)
+    x <- lapply(x, model_parameters, component = component, details = details, ...)
   }
 
   if (!all(sapply(x, inherits, "parameters_model"))) {
@@ -132,6 +142,22 @@ pool_parameters <- function(x, exponentiate = FALSE, component = "conditional",
   }))
 
 
+  # pool random effect variances -----
+
+  pooled_random <- NULL
+  if (details && !is.null(attributes(original_x[[1]])$details)) {
+    pooled_random <- attributes(original_x[[1]])$details
+    n_rows <- nrow(pooled_random)
+    for (i in 1:n_rows) {
+      re <- unlist(lapply(original_x, function(j) {
+        # random effects
+        attributes(j)$details$Value[i]
+      }))
+      pooled_random$Value[i] <- mean(re, na.rm = TRUE)
+    }
+  }
+
+
   # reorder ------
 
   pooled_params$Parameter <- x[[1]]$Parameter
@@ -140,16 +166,20 @@ pool_parameters <- function(x, exponentiate = FALSE, component = "conditional",
 
   # final attributes -----
 
-  if (exponentiate) pooled_params <- .exponentiate_parameters(pooled_params)
+  if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
+    pooled_params <- .exponentiate_parameters(pooled_params, NULL, exponentiate)
+  }
   # this needs to be done extra here, cannot call ".add_model_parameters_attributes()"
   pooled_params <- .add_pooled_params_attributes(
     pooled_params,
     model_params = original_x[[1]],
     model = original_model,
     ci,
-    exponentiate
+    exponentiate,
+    verbose = verbose
   )
   attr(pooled_params, "object_name") <- obj_name
+  attr(pooled_params, "details") <- pooled_random
 
 
   # pool sigma ----
@@ -180,7 +210,7 @@ pool_parameters <- function(x, exponentiate = FALSE, component = "conditional",
   }
   lambda <- (1 + 1 / m) * b / t
   lambda[lambda < 1e-04] <- 1e-04
-  dfold <- (m - 1) / lambda ^ 2
+  dfold <- (m - 1) / lambda^2
   dfobs <- (dfcom + 1) / (dfcom + 3) * dfcom * (1 - lambda)
   dfold * dfobs / (dfold + dfobs)
 }
@@ -188,7 +218,7 @@ pool_parameters <- function(x, exponentiate = FALSE, component = "conditional",
 
 
 #' @importFrom insight find_formula
-.add_pooled_params_attributes <- function(pooled_params, model_params, model, ci, exponentiate) {
+.add_pooled_params_attributes <- function(pooled_params, model_params, model, ci, exponentiate, verbose = TRUE) {
   info <- insight::model_info(model, verbose = FALSE)
   pretty_names <- attributes(model_params)$pretty_names
   if (length(pretty_names) < nrow(model_params)) {
@@ -197,6 +227,7 @@ pool_parameters <- function(x, exponentiate = FALSE, component = "conditional",
   attr(pooled_params, "ci") <- ci
   attr(pooled_params, "exponentiate") <- exponentiate
   attr(pooled_params, "pretty_names") <- pretty_names
+  attr(pooled_params, "verbose") <- verbose
   attr(pooled_params, "ordinal_model") <- attributes(pooled_params)$ordinal_model
   attr(pooled_params, "model_class") <- attributes(pooled_params)$model_class
   attr(pooled_params, "bootstrap") <- attributes(pooled_params)$bootstrap
