@@ -6,18 +6,26 @@ print_md.parameters_model <- function(x,
                                       pretty_names = TRUE,
                                       split_components = TRUE,
                                       select = NULL,
+                                      caption = NULL,
+                                      subtitle = NULL,
+                                      footer = NULL,
                                       digits = 2,
                                       ci_digits = 2,
                                       p_digits = 3,
+                                      ci_brackets = c("(", ")"),
                                       ...) {
   # table caption
   res <- attributes(x)$details
   if (!is.null(attributes(x)$title)) {
     table_caption <- attributes(x)$title
   } else if (!is.null(res)) {
-    table_caption <- "Fixed Effects"
+    if (is.null(caption)) {
+      table_caption <- "Fixed Effects"
+    } else {
+      table_caption <- caption
+    }
   } else {
-    table_caption <- NULL
+    table_caption <- caption
   }
 
   # check if user supplied digits attributes
@@ -25,14 +33,15 @@ print_md.parameters_model <- function(x,
   if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
   if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
 
-
-  formatted_table <- format(x, format = "markdown", pretty_names = pretty_names, split_components = split_components, select = select, digits = digits, ci_digits = ci_digits, p_digits = p_digits, ci_width = NULL, ci_brackets = c("(", ")"))
+  formatted_table <- format(x, format = "markdown", pretty_names = pretty_names, split_components = split_components, select = select, digits = digits, ci_digits = ci_digits, p_digits = p_digits, ci_width = NULL, ci_brackets = ci_brackets)
 
   # replace brackets by parenthesis
-  formatted_table$Parameter <- gsub("[", "(", formatted_table$Parameter, fixed = TRUE)
-  formatted_table$Parameter <- gsub("]", ")", formatted_table$Parameter, fixed = TRUE)
+  if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
+    formatted_table$Parameter <- gsub("[", ci_brackets[1], formatted_table$Parameter, fixed = TRUE)
+    formatted_table$Parameter <- gsub("]", ci_brackets[2], formatted_table$Parameter, fixed = TRUE)
+  }
 
-  insight::export_table(formatted_table, format = "markdown", caption = table_caption, align = "firstleft", ...)
+  insight::export_table(formatted_table, format = "markdown", caption = table_caption, subtitle = subtitle, footer = footer, align = "firstleft", ...)
 }
 
 #' @export
@@ -41,6 +50,36 @@ print_md.parameters_brms_meta <- print_md.parameters_model
 #' @export
 print_md.parameters_simulate <- print_md.parameters_model
 
+#' @export
+print_md.compare_parameters <- function(x,
+                                        digits = 2,
+                                        ci_digits = 2,
+                                        p_digits = 3,
+                                        style = NULL,
+                                        ...) {
+  # save original input
+  orig_x <- x
+
+  # get attributes
+  if (missing(style)) {
+    style <- attributes(x)$output_style
+  }
+
+  formatted_table <- format(
+    x,
+    style,
+    split_components = TRUE,
+    digits = digits,
+    ci_digits = ci_digits,
+    p_digits = p_digits,
+    ci_width = NULL,
+    ci_brackets = c("(", ")"),
+    format = "md"
+  )
+
+  insight::export_table(formatted_table, format = "md", footer = NULL)
+}
+
 
 
 
@@ -48,13 +87,18 @@ print_md.parameters_simulate <- print_md.parameters_model
 # Stan / SEM print ----------------------------
 
 #' @export
-print_md.parameters_sem <- function(x, digits = 2, ci_digits = 2, p_digits = 3, ...) {
+print_md.parameters_sem <- function(x,
+                                    digits = 2,
+                                    ci_digits = 2,
+                                    p_digits = 3,
+                                    ci_brackets = c("(", ")"),
+                                    ...) {
   # check if user supplied digits attributes
   if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
   if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
   if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
 
-  formatted_table <- format(x = x, digits = digits, ci_digits, p_digits = p_digits, format = "markdown", ci_width = NULL, ci_brackets = c("(", ")"), ...)
+  formatted_table <- format(x = x, digits = digits, ci_digits, p_digits = p_digits, format = "markdown", ci_width = NULL, ci_brackets = ci_brackets, ...)
   insight::export_table(formatted_table, format = "markdown", align = "firstleft", ...)
 }
 
@@ -65,7 +109,7 @@ print_md.parameters_stan <- function(x, split_components = TRUE, select = NULL,
   if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
   if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
 
-  formatted_table <- format(split_components = split_components, select = select, format = "markdown", digits = digits, ci_digits, p_digits = p_digits, ci_width = NULL, ci_brackets = c("(", ")"), ...)
+  formatted_table <- format(x = x, split_components = split_components, select = select, format = "markdown", digits = digits, ci_digits, p_digits = p_digits, ci_width = NULL, ci_brackets = c("(", ")"), ...)
   insight::export_table(formatted_table, format = "markdown")
 }
 
@@ -104,8 +148,9 @@ print_md.parameters_pca <- print_md.parameters_efa
 
 # Equivalence test ----------------------------
 
+#' @importFrom insight format_table
 #' @export
-print_md.equivalence_test_lm <- function(x, digits = 2, ...) {
+print_md.equivalence_test_lm <- function(x, digits = 2, ci_brackets = c("(", ")"), ...) {
   rule <- attributes(x)$rule
   rope <- attributes(x)$rope
 
@@ -125,7 +170,7 @@ print_md.equivalence_test_lm <- function(x, digits = 2, ...) {
     x <- x[x$Component %in% c("conditional", "count"), ]
   }
 
-  formatted_table <- insight::parameters_table(x, pretty_names = TRUE, digits = digits, ci_width = NULL, ci_brackets = c("(", ")"), ...)
+  formatted_table <- insight::format_table(x, pretty_names = TRUE, digits = digits, ci_width = NULL, ci_brackets = ci_brackets, ...)
 
   colnames(formatted_table)[which(colnames(formatted_table) == "ROPE_Equivalence")] <- "H0"
   formatted_table$ROPE_low <- NULL
@@ -136,8 +181,10 @@ print_md.equivalence_test_lm <- function(x, digits = 2, ...) {
   formatted_table <- formatted_table[col_order]
 
   # replace brackets by parenthesis
-  formatted_table$Parameter <- gsub("[", "(", formatted_table$Parameter, fixed = TRUE)
-  formatted_table$Parameter <- gsub("]", ")", formatted_table$Parameter, fixed = TRUE)
+  if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
+    formatted_table$Parameter <- gsub("[", ci_brackets[1], formatted_table$Parameter, fixed = TRUE)
+    formatted_table$Parameter <- gsub("]", ci_brackets[2], formatted_table$Parameter, fixed = TRUE)
+  }
 
   if (!is.null(rope)) {
     names(formatted_table)[names(formatted_table) == "% in ROPE"] <- sprintf("%% in ROPE (%.*f, %.*f)", digits, rope[1], digits, rope[2])
@@ -153,8 +200,8 @@ print_md.equivalence_test_lm <- function(x, digits = 2, ...) {
 # distribution print ----------------------------
 
 #' @export
-print_md.parameters_distribution <- function(x, digits = 2, ...) {
-  formatted_table <- format(x = x, digits = digits, format = "markdown",  ci_width = NULL, ci_brackets = c("(", ")"), ...)
+print_md.parameters_distribution <- function(x, digits = 2, ci_brackets = c("(", ")"), ...) {
+  formatted_table <- format(x = x, digits = digits, format = "markdown", ci_width = NULL, ci_brackets = ci_brackets, ...)
   insight::export_table(formatted_table, format = "markdown", align = "firstleft", ...)
 }
 
