@@ -1,4 +1,4 @@
-#' @importFrom utils packageVersion
+#' @importFrom insight is_multivariate model_info find_formula get_data
 #' @keywords internal
 .add_model_parameters_attributes <- function(params,
                                              model,
@@ -26,20 +26,37 @@
     info <- list(family = "unknown", link_function = "unknown")
   }
 
+  if (!is.null(info) && insight::is_multivariate(model) && !"is_zero_inflated" %in% names(info)) {
+    info <- info[[1]]
+  }
+
   if (is.null(attr(params, "pretty_names", exact = TRUE))) {
-    attr(params, "pretty_names") <- format_parameters(model)
+    attr(params, "pretty_names") <- suppressWarnings(format_parameters(model))
   }
   attr(params, "ci") <- ci
   attr(params, "bayes_ci_method") <- ci_method
   attr(params, "verbose") <- verbose
   attr(params, "exponentiate") <- exponentiate
   attr(params, "ordinal_model") <- isTRUE(info$is_ordinal) | isTRUE(info$is_multinomial)
+  attr(params, "linear_model") <- isTRUE(info$is_linear)
+  attr(params, "n_obs") <- info$n_obs
   attr(params, "model_class") <- class(model)
   attr(params, "bootstrap") <- bootstrap
   attr(params, "iterations") <- iterations
   attr(params, "df_method") <- df_method
   attr(params, "p_adjust") <- p_adjust
 
+  weighted_nobs <- tryCatch(
+    {
+      w <- insight::get_weights(model, na_rm = TRUE, null_as_ones = TRUE)
+      round(sum(w))
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+  attr(params, "weighted_nobs") <- weighted_nobs
+
   model_formula <- tryCatch(
     {
       .safe_deparse(insight::find_formula(model)$conditional)
@@ -69,19 +86,17 @@
     attr(params, "study_weights") <- 1 / model$vi
   }
 
-  if (utils::packageVersion("insight") > "0.10.0") {
-    if (inherits(model, c("meta_random", "meta_fixed", "meta_bma"))) {
-      rma_data <- tryCatch(
-        {
-          insight::get_data(model)
-        },
-        error = function(e) {
-          NULL
-        }
-      )
-      attr(params, "data") <- rma_data
-      attr(params, "study_weights") <- 1 / params$SE^2
-    }
+  if (inherits(model, c("meta_random", "meta_fixed", "meta_bma"))) {
+    rma_data <- tryCatch(
+      {
+        insight::get_data(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
+    attr(params, "data") <- rma_data
+    attr(params, "study_weights") <- 1 / params$SE^2
   }
 
   if ("digits" %in% names(dot.arguments)) {
@@ -106,6 +121,20 @@
     attr(params, "s_value") <- eval(dot.arguments[["s_value"]])
   }
 
+  # add CI, and reorder
+  if (!"CI" %in% colnames(params) && length(ci) == 1) {
+    params$CI <- ci
+    ci_pos <- grep("CI_low", colnames(params))
+    if (length(ci_pos)) {
+      if (length(ci_pos) > 1) {
+        ci_pos <- ci_pos[1]
+      }
+      a <- attributes(params)
+      params <- params[c(1:(ci_pos - 1), ncol(params), ci_pos:(ncol(params) - 1))]
+      attributes(params) <- utils::modifyList(a, attributes(params))
+    }
+  }
+
   params
 }
 
@@ -138,8 +167,12 @@
 
 
 
+#' @importFrom insight model_info
 #' @keywords internal
-.exponentiate_parameters <- function(params) {
+.exponentiate_parameters <- function(params, model = NULL, exponentiate = TRUE) {
+  if (!is.null(model) && insight::model_info(model)$is_linear && identical(exponentiate, "nongaussian")) {
+    return(params)
+  }
   columns <- grepl(pattern = "^(Coefficient|Mean|Median|MAP|Std_Coefficient|CI_|Std_CI)", colnames(params))
   if (any(columns)) {
     params[columns] <- exp(params[columns])
@@ -168,12 +201,16 @@
 
 
 #' @keywords internal
-.add_anova_attributes <- function(params, model, ci, ...) {
+.add_anova_attributes <- function(params, model, ci, test = NULL, ...) {
   dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
 
   attr(params, "ci") <- ci
   attr(params, "model_class") <- class(model)
 
+  if (inherits(model, "Anova.mlm") && !identical(test, "univariate")) {
+    attr(params, "anova_test") <- model$test
+  }
+
   if ("digits" %in% names(dot.arguments)) {
     attr(params, "digits") <- eval(dot.arguments[["digits"]])
   } else {
