@@ -1,7 +1,10 @@
-if (require("insight") && require("testthat") && require("parameters")) {
+.runThisTest <- Sys.getenv("RunAllparametersTests") == "yes"
+
+if (.runThisTest && require("insight") && require("testthat") && require("parameters")) {
   data(mtcars)
   m <- glm(am ~ mpg + hp + factor(cyl),
-           data = mtcars, family = binomial())
+    data = mtcars, family = binomial()
+  )
 
   a <- anova(m, test = "Chisq")
   mp <- model_parameters(a)
@@ -45,4 +48,32 @@ if (require("insight") && require("testthat") && require("parameters")) {
       })
     }
   }
+
+  if (require("lme4") && require("effectsize") && utils::packageVersion("effectsize") > "0.4.3") {
+    data(iris)
+    df <- iris
+    df$Sepal.Big <- ifelse(df$Sepal.Width >= 3, "Yes", "No")
+
+    mm <- suppressMessages(lmer(Sepal.Length ~ Sepal.Big + Petal.Width + (1 | Species), data = df))
+    model <- anova(mm)
+
+    # parameters table including effect sizes
+    mp <- model_parameters(
+      model,
+      eta_squared = "partial",
+      ci = .9,
+      df_error = dof_satterthwaite(mm)[2:3]
+    )
+
+    test_that("model_parameters_Anova-effectsize", {
+      expect_equal(
+        colnames(mp),
+        c(
+          "Parameter", "Sum_Squares", "df", "Mean_Square", "F", "Eta2_partial",
+          "Eta2_CI_low", "Eta2_CI_high"
+        )
+      )
+      expect_equal(mp$Eta2_partial, c(0.03262, 0.6778), tolerance = 1e-3)
+    })
+  }
 }
