@@ -7,10 +7,10 @@ if (require("testthat") && require("insight") && require("parameters") && requir
 
   test_that("model_parameters.lme", {
     params <- model_parameters(model)
-    testthat::expect_equal(params$SE, c(6.8245, 1.5458), tolerance = 1e-3)
-    testthat::expect_equal(
+    expect_equal(params$SE, c(6.8245, 1.5458), tolerance = 1e-3)
+    expect_equal(
       colnames(params),
-      c("Parameter", "Coefficient", "SE", "CI_low", "CI_high", "t", "df_error", "p")
+      c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "t", "df_error", "p")
     )
   })
 }
