@@ -6,14 +6,14 @@ if (require("testthat") && require("parameters") && require("bbmle")) {
   LL <- function(ymax = 15, xhalf = 6) {
     -sum(stats::dpois(y, lambda = ymax / (1 + x / xhalf), log = TRUE))
   }
-  model <- mle2(LL)
+  model <- suppressWarnings(mle2(LL))
 
   test_that("model_parameters.mle2", {
     params <- model_parameters(model)
-    testthat::expect_equal(params$SE, c(4.224444, 1.034797), tolerance = 1e-3)
-    testthat::expect_equal(
+    expect_equal(params$SE, c(4.224444, 1.034797), tolerance = 1e-3)
+    expect_equal(
       colnames(params),
-      c("Parameter", "Coefficient", "SE", "CI_low", "CI_high", "z", "df_error", "p")
+      c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "z", "df_error", "p")
     )
   })
 }
