@@ -1,9 +1,8 @@
-if (require("testthat") && require("parameters") && require("psych")) {
-
+if (require("testthat") && require("parameters") && require("psych") && require("nFactors")) {
   test_that("principal_components", {
     x <- parameters::principal_components(mtcars[, 1:7], rotation = "varimax")
 
-    testthat::expect_equal(
+    expect_equal(
       x$RC1,
       c(
         -0.836114674884308,
@@ -17,7 +16,7 @@ if (require("testthat") && require("parameters") && require("psych")) {
       tolerance = 0.01
     )
 
-    testthat::expect_equal(
+    expect_equal(
       colnames(x),
       c("Variable", "RC1", "RC2", "Complexity", "Uniqueness", "MSA")
     )
@@ -27,7 +26,7 @@ if (require("testthat") && require("parameters") && require("psych")) {
   test_that("principal_components", {
     x <- parameters::principal_components(mtcars[, 1:7])
 
-    testthat::expect_equal(
+    expect_equal(
       x$PC1,
       c(
         -0.930866058535747,
@@ -41,9 +40,32 @@ if (require("testthat") && require("parameters") && require("psych")) {
       tolerance = 0.01
     )
 
-    testthat::expect_equal(
+    expect_equal(
       colnames(x),
       c("Variable", "PC1", "PC2", "Complexity")
     )
   })
+
+
+  # predict ----------------------
+
+  data(bfi)
+  d <- na.omit(bfi[, 1:25])
+  model <- psych::fa(d, nfactors = 5)
+  mp <- model_parameters(model, sort = TRUE, threshold = "max")
+
+  test_that("predict model_parameters fa", {
+    pr <- suppressWarnings(predict(mp, names = c("Neuroticism", "Conscientiousness", "Extraversion", "Agreeableness", "Opennness")))
+    out <- head(pr, 5)
+    expect_equal(
+      out$Neuroticism,
+      c(-0.22242, 0.1618, 0.61907, -0.11692, -0.17372),
+      tolerance = 0.01
+    )
+    expect_equal(
+      out$Opennness,
+      c(-1.6092, -0.17222, 0.23341, -1.06152, -0.66086),
+      tolerance = 0.01
+    )
+  })
 }
