@@ -1,6 +1,8 @@
 if (require("testthat") &&
   require("parameters") &&
-  require("plm")) {
+  require("stats") &&
+  require("plm") &&
+  getRversion() > "3.5") {
   data(Crime)
   data("Produc", package = "plm")
   set.seed(123)
@@ -21,7 +23,7 @@ if (require("testthat") &&
     ret = rnorm(9)
   )
   test3333 <- pdata.frame(test3333)
-  test3333["lag"] <- plm::lag(test3333$ret)
+  test3333["lag"] <- lag(test3333$ret)
   test3333 <- na.omit(test3333)
   test3333model <- ret ~ lag
   m3 <- plm::plm(
